document.addEventListener('UniAppJSBridgeReady', () => {
	Vue.createApp({
		data() {
			return {
				Geocoder: null,
				Map: null,
				MapCenter: null,
				LocalSearch: null,
				centerPositionTitle: '',
				centerPositionMiniTitle: '',
				centerPositionTextSelect: false,
				isAnalysisCenterPositionText: false,
				searchText: '',
				addressLists: [],
				top: 0
			}
		},
		mounted() {
			this.Map = new T.Map('map');
			let lon = this.getParams('lon')
			let lat = this.getParams('lat')
			let top = this.getParams('top')
			this.top = top == '' ? 0 : top
			if (lon == '' || lat == '' || isNaN(Number(lon)) || isNaN(Number(lat))) {
				lon = 113.337144
				lat = 22.505658
				this.Map.centerAndZoom(new T.LngLat(lon, lat), 14);
			} else {
				this.Map.centerAndZoom(new T.LngLat(lon, lat), 18);
			}
			this.Map.addEventListener('moveend', this.mapMoveEnd)
			this.Geocoder = new T.Geocoder()
			this.getMapCenter()
			this.getMapCenterPositionTitle()
			this.LocalSearch = new T.LocalSearch(this.Map, {
				pageCapacity: 20,
				onSearchComplete: this.localSearchResult
			})
			this.uniPostMessage({
				type: 'loaded'
			})
		},
		methods: {
			uniPostMessage(data) {
				uni.postMessage({
					data: data
				})
			},
			localSearchResult(result) {
				let resultType = result.getResultType()
				switch (resultType) {
					case 1:
						let data = result.getPois()
						if (typeof data == 'object' && data.length > 0) {
							let addressLists = []
							for (let i = 0; i < data.length; i++) {
								let current = data[i]
								let lonlat = current.lonlat.split(',')
								addressLists.push({
									title: current.name,
									miniTitle: current.address,
									lon: lonlat[0],
									lat: lonlat[1],
									selected: false
								})
							}
							this.addressLists = addressLists
						} else {
							alert('在地图中心点附近搜索不到这个地名 请换一个地名或移动地图中心点搜索试试')
						}
						break
					case 3:
						let lonlat = result.getArea().lonlat.split(',')
						this.Map.centerAndZoom(new T.LngLat(lonlat[0], lonlat[1]), 12);
						break
					default:
						alert('请尝试输入其他字符试试')
						break
				}
			},
			searchBtnClick() {
				this.addressLists = []
				if (this.searchText == '') {
					alert('请输入字符搜索')
				} else {
					this.LocalSearch.search(this.searchText, 1)
				}
			},
			addressItemClick(item) {
				this.allUnSelect()
				item.selected = true
				this.Map.centerAndZoom(new T.LngLat(item.lon, item.lat), 14);
			},
			setCenterPositionTextSelect() {
				this.allUnSelect()
				this.centerPositionTextSelect = true
			},
			allUnSelect() {
				this.centerPositionTextSelect = false
				for (let i = 0; i < this.addressLists.length; i++) {
					this.addressLists[i].selected = false
				}
			},
			mapMoveEnd() {
				this.getMapCenter()
				this.getMapCenterPositionTitle()
			},
			getMapCenter() {
				this.MapCenter = this.Map.getCenter()
			},
			isAllNotSelected() {
				if (this.centerPositionTextSelect) {
					return false
				}
				for (let i = 0; i < this.addressLists.length; i++) {
					if (this.addressLists[i].selected) {
						return false
					}
				}
				return true
			},
			getMapCenterPositionTitle() {
				this.centerPositionTextSelect = false
				this.isAnalysisCenterPositionText = true
				this.Geocoder.getLocation(this.MapCenter, (res) => {
					let data = res.getAddressComponent().addressComponent
					this.centerPositionTitle = '地图选点'
					this.centerPositionMiniTitle = data.province + data.city + data.address
					if (this.isAllNotSelected()) {
						this.setCenterPositionTextSelect()
					}
					this.isAnalysisCenterPositionText = false
				})
			},
			centerPositionTextClick() {
				if (!this.centerPositionTextSelect && !this.isAnalysisCenterPositionText) {
					this.setCenterPositionTextSelect()
				}
			},
			getParams(key) {
				let search = window.location.search.replace(/^\?/, "");
				let pairs = search.split("&");
				let paramsMap = pairs.map(pair => {
					let [key, value] = pair.split("=");
					return [decodeURIComponent(key), decodeURIComponent(value)];
				}).reduce((res, [key, value]) => Object.assign(res, {
					[key]: value
				}), {});
				return paramsMap[key] || "";
			},
			closeBtnClick() {
				this.uniPostMessage({
					type: 'close'
				})
			},
			selectedAddress(address, lon, lat) {
				this.uniPostMessage({
					type: 'selected',
					data: {
						address: address,
						lon: lon,
						lat: lat
					}
				})
			},
			confirmBtnClick() {
				if (this.centerPositionTextSelect) {
					let MapCenter = this.MapCenter
					this.selectedAddress(this.centerPositionMiniTitle, MapCenter.lng, MapCenter.lat)
					return true
				}
				for (let i = 0; i < this.addressLists.length; i++) {
					let current = this.addressLists[i]
					if (current.selected) {
						this.Geocoder.getLocation(T.LngLat(current.lon, current.lat), (res) => {
							let data = res.getAddressComponent().addressComponent
							let address = data.province + data.city + data.address
							let lonlat = res.getLocationPoint()
							this.selectedAddress(address, lonlat.lng, lonlat.lat)
						})
						return true;
					}
				}
				alert('请您点击选择下面的地址')
			}
		}
	}).mount('#app')
})
